#
# spec file for package python-PyMeeus
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-PyMeeus
Version:        0.5.12
Release:        2.3
Summary:        Python implementation of Jean Meeus astronomical routines
License:        LGPL-3.0-only
URL:            https://github.com/architest/pymeeus
Source:         https://files.pythonhosted.org/packages/source/P/PyMeeus/PyMeeus-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
PyMeeus is a Python implementation of the astronomical algorithms
described in the classical book "Astronomical Algorithms, 2nd Edition,
Willmann-Bell Inc. (1998)" by Jean Meeus.

%prep
%setup -q -n PyMeeus-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/*

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Jan  5 2023 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.5.12:
  * Fixed a bug in the computation of the winter solstice. Added new tests and information about proper use of the library.
* Thu Nov 18 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.5.11:
  * Added parameter `local` to the `Epoch` class constructor and
    the methods `get_date()` and `get_full_date()`.
* Wed Mar 17 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.5.10:
  * Added methods ``moon_librations()`` and ``moon_position_angle_axis()``.
  * Added method ``moon_maximum_declination()``.
  * Fixed several bugs in ``Epoch`` class, and added method ``doy()``.
  * Added method ``moon_passage_nodes()``.
  * Added method ``moon_perigee_apogee()``.
  * Added method ``moon_phase()``.
  * Added methods ``illuminated_fraction_disk()`` and ``position_bright_limb()`` to ``Moon`` class.
  * Fixed error in the return type of method `Sun.equation_of_time()`.
  * Added methods to compute the Moon's longitude of ascending node and perigee.
  * Added `Moon` class and `position()` methods.
  * Added method `ring_parameters()` to Saturn class.
  * Added method `__hash__()` to Epoch. Now Epoch objects can be used as keys in a dictionary.
  * Added funtionality to compute the positions of Jupiter's Galilean moons.
  * Added methods to compute Saturn's ring inclination and longitude of ascending node.
  * Additional encoding changes.
  * Deleted `encoding` keyword from setup.py, which was giving problems.
  * Added encoding specification to setup.py.
  * Fixed characters with the wrong encoding.
  * Fixed undefined variable in `Epoch.tt2ut`.
* Wed Apr  1 2020 Marketa Calabkova <mcalabkova@suse.com>
- Initial release (0.3.7)
